@@ -37,7 +37,12 @@ def validate_explainer(rai_insights, X_train, X_test, classes):
     assert isinstance(explanations, list)
     assert len(explanations) == 1
     explanation = explanations[0]
-    num_cols = len(X_train.columns) - 1
+    if rai_insights._feature_metadata is not None and \
+            rai_insights._feature_metadata.dropped_features is not None:
+        num_cols = len(X_train.columns) - 1 - len(
+            rai_insights._feature_metadata.dropped_features)
+    else:
+        num_cols = len(X_train.columns) - 1
     if classes is not None:
         assert len(explanation.local_importance_values) == len(classes)
         assert len(explanation.local_importance_values[0]) == len(X_test)
