@@ -15,6 +15,7 @@ from tests.common_utils import (create_binary_classification_dataset,
 
 from responsibleai import RAIInsights
 from responsibleai.exceptions import UserConfigValidationException
+from responsibleai.feature_metadata import FeatureMetadata
 
 TARGET = 'target'
 
@@ -46,19 +47,20 @@ class TestRAIInsightsValidations:
         X_train[TARGET] = y_train
         X_test[TARGET] = y_test
 
-        with pytest.raises(UserConfigValidationException) as ucve:
+        with pytest.warns(
+                UserWarning,
+                match="The size of test set {0} is greater than "
+                      "supported limit of {1}. Computing insights"
+                      " for first {1} samples "
+                      "of test set".format(len(y_test),
+                                           len(y_test) - 1)):
             RAIInsights(
                 model=model,
                 train=X_train,
                 test=X_test,
-                target_column='bad_target',
+                target_column=TARGET,
                 task_type='classification',
                 maximum_rows_for_test=len(y_test) - 1)
-        assert "The test data has 31 rows, but limit is set to 30 rows" in \
-            str(ucve.value)
-        assert "Please resample the test data or " +\
-            "adjust maximum_rows_for_test" in \
-            str(ucve.value)
 
     def test_empty_train_or_test_datasets(self):
         X_train, X_test, y_train, y_test, _, _ = \
@@ -408,6 +410,45 @@ class TestRAIInsightsValidations:
         assert 'The train labels and distinct values in target ' + \
             '(test data) do not match' in str(ucve.value)
 
+    def test_dataset_exception(self):
+        X_train, X_test, y_train, y_test, _, _ = \
+            create_cancer_data()
+        model = create_lightgbm_classifier(X_train, y_train)
+        X_train_feature_names = X_train.columns.tolist()
+
+        X_train[TARGET] = y_train
+        X_test[TARGET] = y_test
+
+        with pytest.raises(UserConfigValidationException) as ucve:
+            RAIInsights(
+                model=model,
+                train=X_train,
+                test=X_test,
+                target_column=TARGET,
+                task_type='classification',
+                classes=[0, 1],
+                feature_metadata=FeatureMetadata(
+                    dropped_features=X_train_feature_names))
+        assert 'All features have been dropped from the dataset. ' + \
+            'Please do not drop all the features.' in str(ucve.value)
+
+        X_train = pd.DataFrame([], columns=[])
+        X_test = pd.DataFrame([], columns=[])
+        X_train[TARGET] = y_train
+        X_test[TARGET] = y_test
+
+        with pytest.raises(UserConfigValidationException) as ucve:
+            RAIInsights(
+                model=model,
+                train=X_train,
+                test=X_test,
+                target_column=TARGET,
+                task_type='classification',
+                classes=[0, 1])
+        assert 'There is no feature in the dataset. Please make ' + \
+            'sure that your dataset contains at least one feature.' in \
+            str(ucve.value)
+
     def test_classes_passes(self):
         X_train, X_test, y_train, y_test, _, _ = \
             create_cancer_data()
@@ -514,6 +555,52 @@ class TestCausalUserConfigValidations:
         with pytest.raises(UserConfigValidationException, match=message):
             rai_insights.causal.add(treatment_features=['not_a_feature'])
 
+    def test_treatment_features_list_not_having_any_features(self):
+        X_train, y_train, X_test, y_test, _ = \
+            create_binary_classification_dataset()
+
+        model = create_lightgbm_classifier(X_train, y_train)
+        X_train[TARGET] = y_train
+        X_test[TARGET] = y_test
+
+        rai_insights = RAIInsights(
+            model=model,
+            train=X_train,
+            test=X_test,
+            target_column=TARGET,
+            task_type='classification')
+
+        message = ("Please specify at least one feature in "
+                   "treatment_features list")
+        with pytest.raises(UserConfigValidationException, match=message):
+            rai_insights.causal.add(treatment_features=[])
+
+        message = ("Expecting a list for treatment_features but got")
+        with pytest.raises(UserConfigValidationException, match=message):
+            rai_insights.causal.add(treatment_features={})
+
+    def test_treatment_features_having_dropped_features(self):
+        X_train, y_train, X_test, y_test, _ = \
+            create_binary_classification_dataset()
+        train_data = X_train.copy()
+        X_train_dropped = train_data.drop(['col1'], axis=1)
+        model = create_lightgbm_classifier(X_train_dropped, y_train)
+        X_train[TARGET] = y_train
+        X_test[TARGET] = y_test
+        feature_metadata = FeatureMetadata(dropped_features=['col1'])
+        rai_insights = RAIInsights(
+            model=model,
+            train=X_train,
+            test=X_test,
+            target_column=TARGET,
+            task_type='classification',
+            feature_metadata=feature_metadata)
+
+        message = ("'col1' in treatment_features has been dropped "
+                   "during training the model")
+        with pytest.raises(UserConfigValidationException, match=message):
+            rai_insights.causal.add(treatment_features=['col1'])
+
     def test_heterogeneity_features_list_not_having_train_features(self):
         X_train, y_train, X_test, y_test, _ = \
             create_binary_classification_dataset()
